@@ -60,7 +60,7 @@ SQLBindCol(HSTMT StatementHandle,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 
-	mylog("[SQLBindCol]");
+	MYLOG(0, "Entering\n");
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
 	StartRollbackState(stmt);
@@ -74,7 +74,7 @@ SQLBindCol(HSTMT StatementHandle,
 RETCODE		SQL_API
 SQLCancel(HSTMT StatementHandle)
 {
-	mylog("[SQLCancel]");
+	MYLOG(0, "Entering\n");
 	/* Not that neither ENTER_STMT_CS nor StartRollbackState is called */
 	/* SC_clear_error((StatementClass *) StatementHandle); maybe this neither */
 	if (SC_connection_lost_check((StatementClass *) StatementHandle, __FUNCTION__))
@@ -106,7 +106,7 @@ SQLColumns(HSTMT StatementHandle,
 	ConnInfo *ci = &(SC_get_conn(stmt)->connInfo);
 	UWORD	flag	= PODBC_SEARCH_PUBLIC_SCHEMA;
 
-	mylog("[%s]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -183,7 +183,7 @@ SQLConnect(HDBC ConnectionHandle,
 	RETCODE	ret;
 	ConnectionClass *conn = (ConnectionClass *) ConnectionHandle;
 
-	mylog("[SQLConnect]");
+	MYLOG(0, "Entering\n");
 	CC_examine_global_transaction(conn);
 	ENTER_CONN_CS(conn);
 	CC_clear_error(conn);
@@ -206,7 +206,7 @@ SQLDriverConnect(HDBC hdbc,
 	RETCODE	ret;
 	ConnectionClass *conn = (ConnectionClass *) hdbc;
 
-	mylog("[SQLDriverConnect]");
+	MYLOG(0, "Entering\n");
 	CC_examine_global_transaction(conn);
 	ENTER_CONN_CS(conn);
 	CC_clear_error(conn);
@@ -226,7 +226,7 @@ SQLBrowseConnect(HDBC hdbc,
 	RETCODE	ret;
 	ConnectionClass *conn = (ConnectionClass *) hdbc;
 
-	mylog("[SQLBrowseConnect]");
+	MYLOG(0, "Entering\n");
 	CC_examine_global_transaction(conn);
 	ENTER_CONN_CS(conn);
 	CC_clear_error(conn);
@@ -243,7 +243,7 @@ SQLDataSources(HENV EnvironmentHandle,
 			   SQLCHAR *Description, SQLSMALLINT BufferLength2,
 			   SQLSMALLINT *NameLength2)
 {
-	mylog("[SQLDataSources]");
+	MYLOG(0, "Entering\n");
 
 	/*
 	 * return PGAPI_DataSources(EnvironmentHandle, Direction, ServerName,
@@ -263,7 +263,7 @@ SQLDescribeCol(HSTMT StatementHandle,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 
-	mylog("[SQLDescribeCol]");
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -282,11 +282,10 @@ SQLDescribeCol(HSTMT StatementHandle,
 RETCODE		SQL_API
 SQLDisconnect(HDBC ConnectionHandle)
 {
-	CSTR func = "SQLDisconnect";
 	RETCODE	ret;
 	ConnectionClass *conn = (ConnectionClass *) ConnectionHandle;
 
-	mylog("[%s for %p]", func, ConnectionHandle);
+	MYLOG(0, "Entering for %p\n", ConnectionHandle);
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 	if (CC_is_in_global_trans(conn))
 		CALL_DtcOnDisconnect(conn);
@@ -308,7 +307,7 @@ SQLExecDirect(HSTMT StatementHandle,
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 	UWORD	flag = 0;
 
-	mylog("[%s]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -336,7 +335,7 @@ SQLExecute(HSTMT StatementHandle)
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 	UWORD	flag = 0;
 
-	mylog("[%s]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -359,7 +358,6 @@ SQLExecute(HSTMT StatementHandle)
 RETCODE		SQL_API
 SQLFetch(HSTMT StatementHandle)
 {
-	CSTR func = "SQLFetch";
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 	IRDFields	*irdopts = SC_get_IRDF(stmt);
@@ -367,7 +365,7 @@ SQLFetch(HSTMT StatementHandle)
 	SQLUSMALLINT *rowStatusArray = irdopts->rowStatusArray;
 	SQLULEN *pcRow = irdopts->rowsFetched;
 
-	mylog("[[%s]]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -393,7 +391,7 @@ SQLFreeStmt(HSTMT StatementHandle,
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 	ConnectionClass *conn = NULL;
 
-	mylog("[SQLFreeStmt]");
+	MYLOG(0, "Entering\n");
 
 	if (stmt)
 	{
@@ -433,7 +431,7 @@ SQLGetCursorName(HSTMT StatementHandle,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 
-	mylog("[SQLGetCursorName]");
+	MYLOG(0, "Entering\n");
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
 	StartRollbackState(stmt);
@@ -454,7 +452,7 @@ SQLGetData(HSTMT StatementHandle,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 
-	mylog("[SQLGetData]");
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -475,7 +473,7 @@ SQLGetFunctions(HDBC ConnectionHandle,
 	RETCODE	ret;
 	ConnectionClass *conn = (ConnectionClass *) ConnectionHandle;
 
-	mylog("[SQLGetFunctions]");
+	MYLOG(0, "Entering\n");
 	CC_examine_global_transaction(conn);
 	ENTER_CONN_CS(conn);
 	CC_clear_error(conn);
@@ -494,14 +492,13 @@ SQLGetInfo(HDBC ConnectionHandle,
 		   SQLUSMALLINT InfoType, PTR InfoValue,
 		   SQLSMALLINT BufferLength, SQLSMALLINT *StringLength)
 {
-	CSTR	func = "SQLGetInfo";
 	RETCODE		ret;
 	ConnectionClass	*conn = (ConnectionClass *) ConnectionHandle;
 
 	CC_examine_global_transaction(conn);
 	ENTER_CONN_CS(conn);
 	CC_clear_error(conn);
-	mylog("[%s(30)]", func);
+	MYLOG(0, "Entering\n");
 	if ((ret = PGAPI_GetInfo(ConnectionHandle, InfoType, InfoValue,
 				BufferLength, StringLength)) == SQL_ERROR)
 		CC_log_error("SQLGetInfo(30)", "", conn);
@@ -518,7 +515,7 @@ SQLGetTypeInfo(HSTMT StatementHandle,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 
-	mylog("[%s]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check((StatementClass *) StatementHandle, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -544,7 +541,7 @@ SQLNumResultCols(HSTMT StatementHandle,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 
-	mylog("[SQLNumResultCols]");
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -564,7 +561,7 @@ SQLParamData(HSTMT StatementHandle,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 
-	mylog("[SQLParamData]");
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -585,7 +582,7 @@ SQLPrepare(HSTMT StatementHandle,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 
-	mylog("[SQLPrepare]");
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -611,7 +608,7 @@ SQLPutData(HSTMT StatementHandle,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 
-	mylog("[SQLPutData]");
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -630,7 +627,7 @@ SQLRowCount(HSTMT StatementHandle,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 
-	mylog("[SQLRowCount]");
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -652,7 +649,7 @@ SQLSetCursorName(HSTMT StatementHandle,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 
-	mylog("[SQLSetCursorName]");
+	MYLOG(0, "Entering\n");
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
 	StartRollbackState(stmt);
@@ -670,7 +667,7 @@ SQLSetParam(HSTMT StatementHandle,
 			SQLSMALLINT ParameterScale, PTR ParameterValue,
 			SQLLEN *StrLen_or_Ind)
 {
-	mylog("[SQLSetParam]");
+	MYLOG(0, "Entering\n");
 	SC_clear_error((StatementClass *) StatementHandle);
 
 	/*
@@ -696,7 +693,7 @@ SQLSpecialColumns(HSTMT StatementHandle,
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 	SQLCHAR *ctName = CatalogName, *scName = SchemaName, *tbName = TableName;
 
-	mylog("[%s]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -762,7 +759,7 @@ SQLStatistics(HSTMT StatementHandle,
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 	SQLCHAR *ctName = CatalogName, *scName = SchemaName, *tbName = TableName;
 
-	mylog("[%s]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -829,7 +826,7 @@ SQLTables(HSTMT StatementHandle,
 	SQLCHAR *ctName = CatalogName, *scName = SchemaName, *tbName = TableName;
 	UWORD	flag = 0;
 
-	mylog("[%s]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -904,7 +901,7 @@ SQLColumnPrivileges(HSTMT hstmt,
 		*tbName = szTableName, *clName = szColumnName;
 	UWORD	flag = 0;
 
-	mylog("[%s]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -979,7 +976,7 @@ SQLDescribeParam(HSTMT hstmt,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) hstmt;
 
-	mylog("[SQLDescribeParam]");
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -1007,7 +1004,7 @@ SQLExtendedFetch(HSTMT hstmt,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) hstmt;
 
-	mylog("[SQLExtendedFetch]");
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -1054,7 +1051,7 @@ SQLForeignKeys(HSTMT hstmt,
 		*pktbName = szPkTableName, *fkctName = szFkCatalogName,
 		*fkscName = szFkSchemaName, *fktbName = szFkTableName;
 
-	mylog("[%s]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -1139,7 +1136,7 @@ SQLMoreResults(HSTMT hstmt)
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) hstmt;
 
-	mylog("[SQLMoreResults]");
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -1164,7 +1161,7 @@ SQLNativeSql(HDBC hdbc,
 	RETCODE	ret;
 	ConnectionClass *conn = (ConnectionClass *) hdbc;
 
-	mylog("[SQLNativeSql]");
+	MYLOG(0, "Entering\n");
 	CC_examine_global_transaction(conn);
 	ENTER_CONN_CS(conn);
 	CC_clear_error(conn);
@@ -1182,7 +1179,7 @@ SQLNumParams(HSTMT hstmt,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) hstmt;
 
-	mylog("[SQLNumParams]");
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -1211,7 +1208,7 @@ SQLPrimaryKeys(HSTMT hstmt,
 	SQLCHAR	*ctName = szCatalogName, *scName = szSchemaName,
 		*tbName = szTableName;
 
-	mylog("[%s]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -1281,7 +1278,7 @@ SQLProcedureColumns(HSTMT hstmt,
 		*prName = szProcName, *clName = szColumnName;
 	UWORD	flag = 0;
 
-	mylog("[%s]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -1360,7 +1357,7 @@ SQLProcedures(HSTMT hstmt,
 		*prName = szProcName;
 	UWORD	flag = 0;
 
-	mylog("[%s]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -1425,7 +1422,7 @@ SQLSetPos(HSTMT hstmt,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) hstmt;
 
-	mylog("[SQLSetPos]");
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -1455,7 +1452,7 @@ SQLTablePrivileges(HSTMT hstmt,
 		*tbName = szTableName;
 	UWORD	flag = 0;
 
-	mylog("[%s]", func);
+	MYLOG(0, "Entering\n");
 	if (SC_connection_lost_check(stmt, __FUNCTION__))
 		return SQL_ERROR;
 
@@ -1525,7 +1522,7 @@ SQLBindParameter(HSTMT hstmt,
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) hstmt;
 
-	mylog("[SQLBindParameter]");
+	MYLOG(0, "Entering\n");
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
 	StartRollbackState(stmt);
